@@ -23,7 +23,7 @@ def clear():
 	else:
 		os.system("clear")
 
-def prompt(return_type = str):
+def prompt(return_type=str):
 	error = None
 	try:
 		return return_type(input())
@@ -34,3 +34,6 @@ def prompt(return_type = str):
 
 def get_width():
 	return os.get_terminal_size().columns
+
+def colour(ansi_colour):
+	write(f"\u001b[{ansi_colour}m")
